@@ -14,15 +14,15 @@ cd /tmp/ || die "Can't chdir to /tmp/ ."
 
 if [ ! -r kernel-3.9.10-100.fc17.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/17/SRPMS/kernel-3.9.10-100.fc17.src.rpm || die "Can't download source package."
+    wget http://archives.fedoraproject.org/pub/archive/fedora/linux/updates/17/SRPMS/kernel-3.9.10-100.fc17.src.rpm || die "Can't download source package."
 fi
 rpm --checksig kernel-3.9.10-100.fc17.src.rpm || die "Can't verify signature."
 rpm -ivh kernel-3.9.10-100.fc17.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20130825.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20131019.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20130825.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20130825.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20131019.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20131019.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -83,7 +83,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20130825.tar.gz
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20131019.tar.gz
 +patch -sp1 < patches/ccs-patch-3.9-fedora-17.diff
 +
  %endif
